Discover Packages
github.com/captv89/yIntel
models
package
Version:
v0.0.0-...-75cf0d6
Opens a new window with list of versions in this module.
Published: Jul 23, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Chuck struct {
Category []string `json:"category"`
CreatedAt string `json:"created_at"`
IconUrl string `json:"icon_url"`
Id string `json:"id"`
UpdatedAt string `json:"updated_at"`
Url string `json:"url"`
Value string `json:"value"`
}
type Config struct {
TelegramToken string `yaml:"telegram_token"`
AllowedIds []int64 `yaml:"allowed_ids"`
}
type Currency struct {
Date string `json:"date"`
INR float64 `json:"inr"`
}
type DadJoke struct {
ID string `json:"id"`
Joke string `json:"joke"`
Status int `json:"status"`
}
type Meme struct {
PostLink string `json:"postLink"`
SubReddit string `json:"subreddit"`
Title string `json:"title"`
Upvotes int `json:"ups"`
Author string `json:"author"`
URL string `json:"url"`
}
type Story struct {
By string `json:"by"`
Descendants int `json:"descendants"`
ID int `json:"id"`
Kids []int `json:"kids"`
Score int `json:"score"`
Time int `json:"time"`
Title string `json:"title"`
Type string `json:"type"`
URL string `json:"url"`
}
Story is a struct that represents a Hacker News story
Source Files
¶
Click to show internal directories.
Click to hide internal directories.